@@ -92,11 +92,7 @@ static const GtkActionEntry action_entries[] =
 };
 
 static void
-#if GTK_CHECK_VERSION (3, 0, 0)
 sort_dialog_dispose (GObject *obj,
-#else
-sort_dialog_destroy (GtkObject *obj,
-#endif
 		     gpointer  dialog_pointer)
 {
 	pluma_debug (DEBUG_PLUGINS);
@@ -188,7 +184,7 @@ get_sort_dialog (ActionData *action_data)
 		pluma_warning (GTK_WINDOW (action_data->window),
 			       "%s", err_message);
 
-		g_free (dialog);
+		g_slice_free (SortDialog, dialog);
 		gtk_widget_destroy (error_widget);
 
 		return NULL;
@@ -198,13 +194,8 @@ get_sort_dialog (ActionData *action_data)
 					 GTK_RESPONSE_OK);
 
 	g_signal_connect (dialog->dialog,
-#if GTK_CHECK_VERSION (3, 0, 0)
 			  "dispose",
 			  G_CALLBACK (sort_dialog_dispose),
-#else
-			  "destroy",
-			  G_CALLBACK (sort_dialog_destroy),
-#endif
 			  dialog);
 
 	g_signal_connect (dialog->dialog,
