@@ -72,9 +72,7 @@ static const gchar *formats[] =
 	"%a %d %b %Y %H:%M:%S",
 	"%d/%m/%Y",
 	"%d/%m/%y",
-#ifndef G_OS_WIN32
-	"%D", /* This one is not supported on win32 */
-#endif
+	"%D",
 	"%A %d %B %Y",
 	"%A %B %d %Y",
 	"%Y-%m-%d",
@@ -1166,9 +1164,9 @@ configure_dialog_response_cb (GtkWidget           *widget,
 		{
 			pluma_debug_message (DEBUG_PLUGINS, "GTK_RESPONSE_HELP");
 
-			pluma_help_display (GTK_WINDOW (dialog),
+			pluma_help_display (GTK_WINDOW (widget),
 					    NULL,
-					    "pluma-date-time-configure");
+					    "pluma-insert-date-time-plugin#pluma-date-time-configure");
 			break;
 		}
 		case GTK_RESPONSE_OK:
