@@ -1087,7 +1087,7 @@ pluma_preferences_dialog_init (PlumaPreferencesDialog *dlg)
 				GTK_RESPONSE_HELP,
 				NULL);
 
-	gtk_window_set_title (GTK_WINDOW (dlg), _("pluma Preferences"));
+	gtk_window_set_title (GTK_WINDOW (dlg), _("Pluma Preferences"));
 	gtk_window_set_resizable (GTK_WINDOW (dlg), FALSE);
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (dlg), TRUE);
 
