@@ -46,10 +46,6 @@
 #include "pluma-enum-types.h"
 #include "pluma-dirs.h"
 
-#ifdef OS_OSX
-#include <ige-mac-integration.h>
-#endif
-
 #define PLUMA_PAGE_SETUP_FILE		"pluma-page-setup"
 #define PLUMA_PRINT_SETTINGS_FILE	"pluma-print-settings"
 
@@ -440,14 +436,6 @@ window_destroy (PlumaWindow *window,
 */
 	if (app->priv->windows == NULL)
 	{
-#ifdef OS_OSX
-		if (!GPOINTER_TO_INT (g_object_get_data (G_OBJECT (window), "pluma-is-quitting-all")))
-		{
-			/* Create hidden proxy window on OS X to handle the menu */
-			pluma_app_create_window (app, NULL);
-			return;
-		}
-#endif
 		/* Last window is gone... save some settings and exit */
 		ensure_user_config_dir ();
 
@@ -563,6 +551,7 @@ pluma_app_create_window_real (PlumaApp    *app,
 /**
  * pluma_app_create_window:
  * @app: the #PlumaApp
+ * @screen: (allow-none):
  *
  * Create a new #PlumaWindow part of @app.
  *
@@ -603,8 +592,8 @@ _pluma_app_restore_window (PlumaApp    *app,
  *
  * Returns all the windows currently present in #PlumaApp.
  *
- * Return value: the list of #PlumaWindows objects. The list
- * should not be freed
+ * Return value: (transfer none): the list of #PlumaWindows objects.
+ * The list should not be freed
  */
 const GList *
 pluma_app_get_windows (PlumaApp *app)
@@ -749,7 +738,8 @@ _pluma_app_get_window_in_viewport (PlumaApp  *app,
  *
  * Returns all the documents currently open in #PlumaApp.
  *
- * Return value: a newly allocated list of #PlumaDocument objects
+ * Return value: (element-type Pluma.Document) (transfer container):
+ * a newly allocated list of #PlumaDocument objects
  */
 GList *
 pluma_app_get_documents	(PlumaApp *app)
@@ -778,7 +768,8 @@ pluma_app_get_documents	(PlumaApp *app)
  *
  * Returns all the views currently present in #PlumaApp.
  *
- * Return value: a newly allocated list of #PlumaView objects
+ * Return value: (element-type Pluma.View) (transfer container):
+ * a newly allocated list of #PlumaView objects
  */
 GList *
 pluma_app_get_views (PlumaApp *app)
