@@ -37,7 +37,9 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+#ifdef WITH_MATEDESKTOP
 #include <libmate-desktop/mate-aboutdialog.h>
+#endif
 
 #include "pluma-commands.h"
 #include "pluma-debug.h"
@@ -81,12 +83,17 @@ void _pluma_cmd_help_about(GtkAction* action, PlumaWindow* window)
 		"Copyright \xc2\xa9 2012-2014 MATE developers";
 
 	static const gchar comments[] = \
-		N_("pluma is a small and lightweight text editor for the MATE Desktop");
+		N_("Pluma is a small and lightweight text editor for the MATE Desktop");
 
 	pluma_debug (DEBUG_COMMANDS);
 
+#ifdef WITH_MATEDESKTOP
 	mate_show_about_dialog(GTK_WINDOW(window),
+#else
+	gtk_show_about_dialog(GTK_WINDOW(window),
+#endif
 		"program-name", "Pluma",
+
 		"authors", authors,
 		"comments", _(comments),
 		"copyright", copyright,
