@@ -34,9 +34,6 @@
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
 #include <gdk/gdkkeysyms.h>
-#if GTK_CHECK_VERSION (3, 0, 0)
-#include <gdk/gdkkeysyms-compat.h>
-#endif
 
 #include "pluma-close-button.h"
 #include "pluma-window.h"
@@ -244,15 +241,15 @@ pluma_panel_class_init (PlumaPanelClass *klass)
 			      G_TYPE_NONE, 0);					
 	binding_set = gtk_binding_set_by_class (klass);
 
-	gtk_binding_entry_add_signal (binding_set, 
-				      GDK_Escape, 
-				      0, 
-				      "close", 
+	gtk_binding_entry_add_signal (binding_set,
+				      GDK_KEY_Escape,
+				      0,
+				      "close",
 				      0);
-	gtk_binding_entry_add_signal (binding_set, 
-				      GDK_Return, 
-				      GDK_CONTROL_MASK, 
-				      "focus_document", 
+	gtk_binding_entry_add_signal (binding_set,
+				      GDK_KEY_Return,
+				      GDK_CONTROL_MASK,
+				      "focus_document",
 				      0);
 }
 
@@ -741,9 +738,9 @@ pluma_panel_add_item_with_stock_icon (PlumaPanel  *panel,
  * @item: the item to be removed from the panel
  *
  * Removes the widget @item from the panel if it is in the @panel and returns
- * TRUE if there was not any problem.
+ * %TRUE if there was not any problem.
  *
- * Returns: TRUE if it was well removed.
+ * Returns: %TRUE if it was well removed.
  */
 gboolean
 pluma_panel_remove_item (PlumaPanel *panel,
@@ -796,7 +793,7 @@ pluma_panel_remove_item (PlumaPanel *panel,
  *
  * Switches to the page that contains @item.
  *
- * Returns: TRUE if it was activated
+ * Returns: %TRUE if it was activated
  */
 gboolean
 pluma_panel_activate_item (PlumaPanel *panel,
@@ -822,11 +819,11 @@ pluma_panel_activate_item (PlumaPanel *panel,
 /**
  * pluma_panel_item_is_active:
  * @panel: a #PlumaPanel
- * @item: a widget contained in #PlumaPanel
+ * @item: a #GtkWidget
  *
- * Whether @item is the one current active in @panel
+ * Returns whether @item is the active widget in @panel
  *
- * Returns: TRUE if the widget is active
+ * Returns: %TRUE if @item is the active widget
  */
 gboolean
 pluma_panel_item_is_active (PlumaPanel *panel,
