@@ -39,10 +39,6 @@
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#if GTK_CHECK_VERSION (3, 0, 0)
-#include <gdk/gdkkeysyms-compat.h>
-#include <gtksourceview/gtksourceview.h>
-#endif
 
 #include <glib/gi18n.h>
 
@@ -173,7 +169,7 @@ typedef enum
 {
 	PLUMA_SEARCH_ENTRY_NORMAL,
 	PLUMA_SEARCH_ENTRY_NOT_FOUND
-} PlumaSearchEntryBgColor;
+} PlumaSearchEntryState;
 
 static void
 document_read_only_notify_handler (PlumaDocument *document, 
@@ -279,22 +275,22 @@ pluma_view_class_init (PlumaViewClass *klass)
 	binding_set = gtk_binding_set_by_class (klass);
 	
 	gtk_binding_entry_add_signal (binding_set,
-				      GDK_k,
+				      GDK_KEY_k,
 				      GDK_CONTROL_MASK,
 				      "start_interactive_search", 0);
 		
 	gtk_binding_entry_add_signal (binding_set,
-				      GDK_i,
+				      GDK_KEY_i,
 				      GDK_CONTROL_MASK,
 				      "start_interactive_goto_line", 0);
 	
 	gtk_binding_entry_add_signal (binding_set,
-				      GDK_k,
+				      GDK_KEY_k,
 				      GDK_CONTROL_MASK | GDK_SHIFT_MASK,
 				      "reset_searched_text", 0);
 
 	gtk_binding_entry_add_signal (binding_set, 
-				      GDK_d, 
+				      GDK_KEY_d,
 				      GDK_CONTROL_MASK,
 				      "delete_from_cursor", 2,
 				      G_TYPE_ENUM, GTK_DELETE_PARAGRAPHS,
@@ -467,7 +463,7 @@ pluma_view_focus_out (GtkWidget *widget, GdkEventFocus *event)
  * @doc: a #PlumaDocument
  * 
  * Creates a new #PlumaView object displaying the @doc document. 
- * @doc cannot be NULL.
+ * @doc cannot be %NULL.
  *
  * Return value: a new #PlumaView
  **/
@@ -653,6 +649,7 @@ pluma_view_scroll_to_cursor (PlumaView *view)
 				      0.0);
 }
 
+/* FIXME this is an issue for introspection */
 /**
  * pluma_view_set_font:
  * @view: a #PlumaView
@@ -759,11 +756,18 @@ add_search_completion_entry (const gchar *str)
 }
 
 static void
-set_entry_background (GtkWidget               *entry,
-		      PlumaSearchEntryBgColor  col)
+set_entry_state (GtkWidget             *entry,
+                 PlumaSearchEntryState  state)
 {
-	if (col == PLUMA_SEARCH_ENTRY_NOT_FOUND)
+#if GTK_CHECK_VERSION (3, 0 ,0)
+	GtkStyleContext *context = gtk_widget_get_style_context (GTK_WIDGET (entry));
+#endif
+
+	if (state == PLUMA_SEARCH_ENTRY_NOT_FOUND)
 	{
+#if GTK_CHECK_VERSION (3, 0 ,0)
+		gtk_style_context_add_class (context, GTK_STYLE_CLASS_ERROR);
+#else
 		GdkColor red;
 		GdkColor white;
 
@@ -778,15 +782,20 @@ set_entry_background (GtkWidget               *entry,
 		gtk_widget_modify_text (entry,
 				        GTK_STATE_NORMAL,
 				        &white);
+#endif
 	}
 	else /* reset */
 	{
+#if GTK_CHECK_VERSION (3, 0 ,0)
+		gtk_style_context_remove_class (context, GTK_STYLE_CLASS_ERROR);
+#else
 		gtk_widget_modify_base (entry,
 				        GTK_STATE_NORMAL,
 				        NULL);
 		gtk_widget_modify_text (entry,
 				        GTK_STATE_NORMAL,
 				        NULL);
+#endif
 	}
 }
 
@@ -895,13 +904,13 @@ run_search (PlumaView        *view,
 	{				   
 		pluma_view_scroll_to_cursor (view);
 
-		set_entry_background (view->priv->search_entry,
-				      PLUMA_SEARCH_ENTRY_NORMAL);	
+		set_entry_state (view->priv->search_entry,
+		                 PLUMA_SEARCH_ENTRY_NORMAL);
 	}
 	else
 	{
-		set_entry_background (view->priv->search_entry,
-				      PLUMA_SEARCH_ENTRY_NOT_FOUND);
+		set_entry_state (view->priv->search_entry,
+		                 PLUMA_SEARCH_ENTRY_NOT_FOUND);
 	}
 
 	return found;
@@ -1084,14 +1093,14 @@ search_window_key_press_event (GtkWidget   *widget,
 	modifiers = gtk_accelerator_get_default_mod_mask ();
 
 	/* Close window */
-	if (event->keyval == GDK_Tab)
+	if (event->keyval == GDK_KEY_Tab)
 	{
 		hide_search_window (view, FALSE);
 		retval = TRUE;
 	}
 
 	/* Close window and cancel the search */
-	if (event->keyval == GDK_Escape)
+	if (event->keyval == GDK_KEY_Escape)
 	{
 		if (view->priv->search_mode == SEARCH)
 		{
@@ -1115,28 +1124,28 @@ search_window_key_press_event (GtkWidget   *widget,
 	/* SEARCH mode */
 
 	/* select previous matching iter */
-	if (event->keyval == GDK_Up || event->keyval == GDK_KP_Up)
+	if (event->keyval == GDK_KEY_Up || event->keyval == GDK_KEY_KP_Up)
 	{
 		search_again (view, TRUE);
 		retval = TRUE;
 	}
 
 	if (((event->state & modifiers) == (GDK_CONTROL_MASK | GDK_SHIFT_MASK)) && 
-	    (event->keyval == GDK_g || event->keyval == GDK_G))
+	    (event->keyval == GDK_KEY_g || event->keyval == GDK_KEY_G))
 	{
 		search_again (view, TRUE);
 		retval = TRUE;
 	}
 
 	/* select next matching iter */
-	if (event->keyval == GDK_Down || event->keyval == GDK_KP_Down)
+	if (event->keyval == GDK_KEY_Down || event->keyval == GDK_KEY_KP_Down)
 	{
 		search_again (view, FALSE);
 		retval = TRUE;
 	}
 
 	if (((event->state & modifiers) == GDK_CONTROL_MASK) && 
-	    (event->keyval == GDK_g || event->keyval == GDK_G))
+	    (event->keyval == GDK_KEY_g || event->keyval == GDK_KEY_G))
 	{
 		search_again (view, FALSE);
 		retval = TRUE;
@@ -1623,12 +1632,11 @@ init_search_entry (PlumaView *view)
 		guint     old_find_flags = 0;
 		gint      sel_len = 0;
 
-		g_free (view->priv->old_search_text);
-		
 		old_find_text = pluma_document_get_search_text (PLUMA_DOCUMENT (buffer), 
 								&old_find_flags);
 		if (old_find_text != NULL)
 		{
+			g_free (view->priv->old_search_text);
 			view->priv->old_search_text = old_find_text;
 			add_search_completion_entry (old_find_text);
 		}
@@ -1761,11 +1769,11 @@ search_init (GtkWidget *entry,
 			pluma_view_scroll_to_cursor (view);
 
 			if (!moved || !moved_offset)
-				set_entry_background (view->priv->search_entry,
-						      PLUMA_SEARCH_ENTRY_NOT_FOUND);
+				set_entry_state (view->priv->search_entry,
+				                 PLUMA_SEARCH_ENTRY_NOT_FOUND);
 			else
-				set_entry_background (view->priv->search_entry,
-						      PLUMA_SEARCH_ENTRY_NORMAL);
+				set_entry_state (view->priv->search_entry,
+				                 PLUMA_SEARCH_ENTRY_NORMAL);
 		}
 	}
 }
@@ -2114,19 +2122,6 @@ search_highlight_updated_cb (PlumaDocument *doc,
 	}
 }
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-/* There is no "official" way to reset the im context in GtkTextView */
-static void
-reset_im_context (GtkTextView *text_view)
-{
-	if (text_view->need_im_reset)
-	{
-		text_view->need_im_reset = FALSE;
-		gtk_im_context_reset (text_view->im_context);
-	}
-}
-#endif
-
 static void
 delete_line (GtkTextView *text_view,
 	     gint         count)
