@@ -21,9 +21,11 @@
  */
 
 #include "pluma-gio-document-loader.h"
+#include "pluma-prefs-manager-app.h"
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 #include <glib.h>
+#include <glib/gprintf.h>
 #include <string.h>
 #include <sys/stat.h>
 
@@ -357,7 +359,6 @@ test_remote ()
 	            saver_test_data_new (DEFAULT_REMOTE_URI, "hello world\n\n", NULL));
 }
 
-#ifndef G_OS_WIN32
 static void
 check_permissions (GFile *file,
                    guint  permissions)
@@ -453,7 +454,6 @@ test_local_permissions ()
 	test_permissions (DEFAULT_LOCAL_URI, 0666);
 	test_permissions (DEFAULT_LOCAL_URI, 0760);
 }
-#endif
 
 static void
 test_local_unowned_directory ()
@@ -481,7 +481,6 @@ test_remote_unowned_directory ()
 	                                 NULL));
 }
 
-#ifndef G_OS_WIN32
 static void
 test_remote_permissions ()
 {
@@ -546,8 +545,6 @@ test_remote_unowned_group ()
 	test_unowned_group (UNOWNED_GROUP_REMOTE_URI);
 }
 
-#endif
-
 static gboolean
 check_unowned_directory ()
 {
@@ -663,7 +660,6 @@ check_unowned_group ()
 		return FALSE;
 	}
 
-#ifndef G_OS_WIN32
 	if ((g_file_info_get_attribute_uint32 (info, G_FILE_ATTRIBUTE_UNIX_MODE) & ACCESSPERMS) != 0660)
 	{
 		g_object_unref (unowned);
@@ -672,7 +668,6 @@ check_unowned_group ()
 		g_object_unref (info);
 		return FALSE;
 	}
-#endif
 
 	g_object_unref (info);
 	g_object_unref (unowned);
@@ -719,7 +714,6 @@ int main (int   argc,
 		/* g_test_add_func ("/document-saver/remote-unowned-group", test_remote_unowned_group); */
 	}
 
-#ifndef G_OS_WIN32
 	g_test_add_func ("/document-saver/local-permissions", test_local_permissions);
 
 	if (have_unowned_group)
@@ -728,7 +722,6 @@ int main (int   argc,
 	}
 
 	g_test_add_func ("/document-saver/remote-permissions", test_remote_permissions);
-#endif
 
 	return g_test_run ();
 }
